==> open-cluster-management-operator-model-6.3.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/MultiClusterHubListFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface MultiClusterHubListFluent<A extends MultiClusterHubListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,MultiClusterHub item);
  public A setToItems(Integer index,MultiClusterHub item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHub... items);
  public A addAllToItems(Collection<MultiClusterHub> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHub... items);
  public A removeAllFromItems(Collection<MultiClusterHub> items);
  public A removeMatchingFromItems(Predicate<MultiClusterHubBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<MultiClusterHub> getItems();
  public List<MultiClusterHub> buildItems();
  public MultiClusterHub buildItem(Integer index);
  public MultiClusterHub buildFirstItem();
  public MultiClusterHub buildLastItem();
  public MultiClusterHub buildMatchingItem(Predicate<MultiClusterHubBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<MultiClusterHubBuilder> predicate);
  public A withItems(List<MultiClusterHub> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHub... items);
  public Boolean hasItems();
  public MultiClusterHubListFluent.ItemsNested<A> addNewItem();
  public MultiClusterHubListFluent.ItemsNested<A> addNewItemLike(MultiClusterHub item);
  public MultiClusterHubListFluent.ItemsNested<A> setNewItemLike(Integer index,MultiClusterHub item);
  public MultiClusterHubListFluent.ItemsNested<A> editItem(Integer index);
  public MultiClusterHubListFluent.ItemsNested<A> editFirstItem();
  public MultiClusterHubListFluent.ItemsNested<A> editLastItem();
  public MultiClusterHubListFluent.ItemsNested<A> editMatchingItem(Predicate<MultiClusterHubBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,MultiClusterHubFluent<MultiClusterHubListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> open-cluster-management-operator-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/MultiClusterHubListFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface MultiClusterHubListFluent<A extends MultiClusterHubListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,MultiClusterHub item);
  public A setToItems(int index,MultiClusterHub item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHub... items);
  public A addAllToItems(Collection<MultiClusterHub> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHub... items);
  public A removeAllFromItems(Collection<MultiClusterHub> items);
  public A removeMatchingFromItems(Predicate<MultiClusterHubBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<MultiClusterHub> getItems();
  public List<MultiClusterHub> buildItems();
  public MultiClusterHub buildItem(int index);
  public MultiClusterHub buildFirstItem();
  public MultiClusterHub buildLastItem();
  public MultiClusterHub buildMatchingItem(Predicate<MultiClusterHubBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<MultiClusterHubBuilder> predicate);
  public A withItems(List<MultiClusterHub> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHub... items);
  public Boolean hasItems();
  public MultiClusterHubListFluent.ItemsNested<A> addNewItem();
  public MultiClusterHubListFluent.ItemsNested<A> addNewItemLike(MultiClusterHub item);
  public MultiClusterHubListFluent.ItemsNested<A> setNewItemLike(int index,MultiClusterHub item);
  public MultiClusterHubListFluent.ItemsNested<A> editItem(int index);
  public MultiClusterHubListFluent.ItemsNested<A> editFirstItem();
  public MultiClusterHubListFluent.ItemsNested<A> editLastItem();
  public MultiClusterHubListFluent.ItemsNested<A> editMatchingItem(Predicate<MultiClusterHubBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,MultiClusterHubFluent<MultiClusterHubListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
